==> PyHockeyStats-0.5.0-py2-none-any.whl: libhockeydata/versioninfo.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2015-2021 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2015-2021 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: versioninfo.py - Last Update: 3/10/2021 Ver. 0.5.0 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import datetime, platform;

linuxdist = None;
try:
 linuxdist = platform.linux_distribution();
except AttributeError:
 linuxdist = None;

python_info = {'python_branch': platform.python_branch(), 'python_build': platform.python_build(), 'python_compiler': platform.python_compiler(), 'python_implementation': platform.python_implementation(), 'python_revision': platform.python_revision(), 'python_version': platform.python_version(), 'python_version_tuple': platform.python_version_tuple(), 'release': platform.release(), 'system': platform.system(), 'uname': platform.uname(), 'architecture': platform.architecture(), 'machine': platform.machine(), 'node': platform.node(), 'platform': platform.platform(), 'processor': platform.processor(), 'version': platform.version(), 'java_ver': platform.java_ver(), 'win32_ver': platform.win32_ver(), 'mac_ver': platform.mac_ver(), 'linux_distribution': linuxdist, 'libc_ver': platform.libc_ver()};
def get_python_info(infotype=None):
 global python_info;
 python_info = python_info;
 if(infotype is None):
  return python_info;
 if(infotype is not None):
  return python_info.get(infotype, python_info);

getcuryear = datetime.date.today().year;
if(getcuryear <= 2015):
 getcuryear = 2016;
getcuryear = str(getcuryear);
__author__ = "Kazuki Przyborowski";
__copyright__ = "(C) Game Maker 2k @ 2015-"+getcuryear;
__credits__ = ["Kazuki Przyborowski", "Game Maker 2k"];
__copyright_year__ = "2015-"+getcuryear;
__license__ = "Revised BSD License";
__license_string__ = """-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
            Revised BSD License

Copyright (C) 2011-2020 Game Maker 2k. 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice,
     this list of conditions and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright 
     notice, this list of conditions and the following disclaimer in 
     the documentation and/or other materials provided with the distribution.

  3. Neither the name of Game Maker 2k nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Game Maker 2k.
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-""";
__maintainer__ = "Kazuki Przyborowski";
__email__ = "kazuki.przyborowski@gmail.com";
__status__ = "Production";
__program_name__ = "PyHockeyStats";
__program_alt_name__ = "PyHockeyData";
__project__ = __program_name__;
__project_url__ = "https://github.com/GameMaker2k/Neo-Hockey-Test";
__project_release_url__ = "https://github.com/GameMaker2k/Neo-Hockey-Test/releases/latest";
__version_info__ = (0, 5, 0, "RC 1", 1);
__build_time__ = {"timestamp": 1616056301, "year": 2021, "month": 3, "day": 18, "hour": 3, "minute": 31, "second": 41};
__build_time_utc__ = {"timestamp": 1616074301, "year": 2021, "month": 3, "day": 18, "hour": 8, "minute": 31, "second": 41};
__build_python_info__ = {'node': 'DESKTOP-8SMU86M', 'machine': 'x86_64', 'python_revision': '', 'platform': 'Linux-4.19.128-microsoft-standard-x86_64-with-glibc2.2.5', 'python_branch': '', 'python_implementation': 'CPython', 'python_build': ('default', 'Sep  5 2020 11:17:26'), 'mac_ver': ('', ('', '', ''), ''), 'system': 'Linux', 'win32_ver': ('', '', '', ''), 'python_version_tuple': ('2', '7', '18'), 'uname': ('Linux', 'DESKTOP-8SMU86M', '4.19.128-microsoft-standard', '#1 SMP Tue Jun 23 12:58:10 UTC 2020', 'x86_64', ''), 'version': '#1 SMP Tue Jun 23 12:58:10 UTC 2020', 'libc_ver': ('glibc', '2.2.5'), 'architecture': ('64bit', 'ELF'), 'java_ver': ('', '', ('', '', ''), ('', '', '')), 'release': '4.19.128-microsoft-standard', 'python_compiler': 'GCC 10.2.0', 'linux_distribution': ('', '', ''), 'processor': '', 'python_version': '2.7.18'};
__build_python_is_set__ = True;
if(not __build_python_is_set__):
 __build_python_info__ = python_info;
def get_build_python_info(infotype=None):
 global __build_python_info__;
 python_info = __build_python_info__;
 if(infotype is None):
  return python_info;
 if(infotype is not None):
  return python_info.get(infotype, python_info);
__revision__ = __version_info__[3];
__revision_id__ = "$Id: ddec86069df108c3c9cfb8fa005a123cf4a7b434 $";
if(__version_info__[3] is not None):
 __version__ = "{major}.{minor}.{build} {release}".format(major=__version_info__[0], minor=__version_info__[1], build=__version_info__[2], release=__version_info__[3]);
if(__version_info__[3] is None):
 __version__ = "{major}.{minor}.{build}".format(major=__version_info__[0], minor=__version_info__[1], build=__version_info__[2]);
__version_alt__ = "{major}.{minor}.{build}".format(major=__version_info__[0], minor=__version_info__[1], build=__version_info__[2]);
def version_info():
 if(__version_info__[3] is not None):
  return {"major": __version_info__[0], "minor": __version_info__[1], "build": __version_info__[2], "release": __version_info__[3]};
 if(__version_info__[3] is None):
  return {"major": __version_info__[0], "minor": __version_info__[1], "build": __version_info__[2], "release": None};
__version_date_info__ = (2021, 3, 10, "RC 1", 1);
def version_date():
 if(__version_date_info__[3] is not None):
  return {"year":__version_date_info__[0], "month": __version_date_info__[1], "day": __version_date_info__[2], "release": __version_date_info__[3]};
 if(__version_date_info__[3] is None):
  return {"year":__version_date_info__[0], "month": __version_date_info__[1], "day": __version_date_info__[2], "release": None};
__version_date__ = "{year}.{month}.{day}".format(year=__version_date_info__[0], month=__version_date_info__[1], day=__version_date_info__[2]);
__version_date_alt__ = "{year}.{month}.{day} {release}".format(year=__version_date_info__[0], month=__version_date_info__[1], day=__version_date_info__[2], release=__version_date_info__[2]);
if(__version_date_info__[4] is not None):
 __version_date_plusrc__ = __version_date__+"-"+str(__version_date_info__[4]);
if(__version_date_info__[4] is None):
 __version_date_plusrc__ = __version_date__;
if(__version_info__[4] is not None):
 __version_plusrc__ = __version__+"-"+str(__version_info__[4]);
if(__version_info__[4] is None):
 __version_plusrc__ = __version__;

==> PyHockeyStats-0.5.2-py2-none-any.whl: libhockeydata/versioninfo.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2015-2021 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2015-2021 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: versioninfo.py - Last Update: 3/10/2021 Ver. 0.6.0 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import datetime, platform;

linuxdist = None;
try:
 linuxdist = platform.linux_distribution();
except AttributeError:
 linuxdist = None;

python_info = {'python_branch': platform.python_branch(), 'python_build': platform.python_build(), 'python_compiler': platform.python_compiler(), 'python_implementation': platform.python_implementation(), 'python_revision': platform.python_revision(), 'python_version': platform.python_version(), 'python_version_tuple': platform.python_version_tuple(), 'release': platform.release(), 'system': platform.system(), 'uname': platform.uname(), 'architecture': platform.architecture(), 'machine': platform.machine(), 'node': platform.node(), 'platform': platform.platform(), 'processor': platform.processor(), 'version': platform.version(), 'java_ver': platform.java_ver(), 'win32_ver': platform.win32_ver(), 'mac_ver': platform.mac_ver(), 'linux_distribution': linuxdist, 'libc_ver': platform.libc_ver()};
def get_python_info(infotype=None):
 global python_info;
 python_info = python_info;
 if(infotype is None):
  return python_info;
 if(infotype is not None):
  return python_info.get(infotype, python_info);

getcuryear = datetime.date.today().year;
if(getcuryear <= 2015):
 getcuryear = 2016;
getcuryear = str(getcuryear);
__author__ = "Kazuki Przyborowski";
__copyright__ = "(C) Game Maker 2k @ 2015-"+getcuryear;
__credits__ = ["Kazuki Przyborowski", "Game Maker 2k"];
__copyright_year__ = "2015-"+getcuryear;
__license__ = "Revised BSD License";
__license_string__ = """-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
            Revised BSD License

Copyright (C) 2011-2020 Game Maker 2k. 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice,
     this list of conditions and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright 
     notice, this list of conditions and the following disclaimer in 
     the documentation and/or other materials provided with the distribution.

  3. Neither the name of Game Maker 2k nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Game Maker 2k.
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-""";
__maintainer__ = "Kazuki Przyborowski";
__email__ = "kazuki.przyborowski@gmail.com";
__status__ = "Production";
__program_name__ = "PyHockeyStats";
__program_alt_name__ = "PyHockeyData";
__project__ = __program_name__;
__project_url__ = "https://github.com/GameMaker2k/Neo-Hockey-Test";
__project_release_url__ = "https://github.com/GameMaker2k/Neo-Hockey-Test/releases/latest";
__version_info__ = (0, 5, 2, "RC 1", 1);
__build_time__ = {"timestamp": 1618390744, "year": 2021, "month": 4, "day": 14, "hour": 3, "minute": 59, "second": 4};
__build_time_utc__ = {"timestamp": 1618408744, "year": 2021, "month": 4, "day": 14, "hour": 8, "minute": 59, "second": 4};
__build_python_info__ = {'node': 'DESKTOP-8SMU86M', 'machine': 'x86_64', 'python_revision': '', 'platform': 'Linux-4.19.128-microsoft-standard-x86_64-with-glibc2.2.5', 'python_branch': '', 'python_implementation': 'CPython', 'python_build': ('default', 'Mar 15 2021 14:29:03'), 'mac_ver': ('', ('', '', ''), ''), 'system': 'Linux', 'win32_ver': ('', '', '', ''), 'python_version_tuple': ('2', '7', '18'), 'uname': ('Linux', 'DESKTOP-8SMU86M', '4.19.128-microsoft-standard', '#1 SMP Tue Jun 23 12:58:10 UTC 2020', 'x86_64', ''), 'version': '#1 SMP Tue Jun 23 12:58:10 UTC 2020', 'libc_ver': ('glibc', '2.2.5'), 'architecture': ('64bit', 'ELF'), 'java_ver': ('', '', ('', '', ''), ('', '', '')), 'release': '4.19.128-microsoft-standard', 'python_compiler': 'GCC 10.2.0', 'linux_distribution': ('', '', ''), 'processor': '', 'python_version': '2.7.18'};
__build_python_is_set__ = True;
if(not __build_python_is_set__):
 __build_python_info__ = python_info;
def get_build_python_info(infotype=None):
 global __build_python_info__;
 python_info = __build_python_info__;
 if(infotype is None):
  return python_info;
 if(infotype is not None):
  return python_info.get(infotype, python_info);
__revision__ = __version_info__[3];
__revision_id__ = "$Id: 164c440ee59f966d228659b2bb8eb5ec31457dbc $";
if(__version_info__[3] is not None):
 __version__ = "{major}.{minor}.{build} {release}".format(major=__version_info__[0], minor=__version_info__[1], build=__version_info__[2], release=__version_info__[3]);
if(__version_info__[3] is None):
 __version__ = "{major}.{minor}.{build}".format(major=__version_info__[0], minor=__version_info__[1], build=__version_info__[2]);
__version_alt__ = "{major}.{minor}.{build}".format(major=__version_info__[0], minor=__version_info__[1], build=__version_info__[2]);
def version_info():
 if(__version_info__[3] is not None):
  return {"major": __version_info__[0], "minor": __version_info__[1], "build": __version_info__[2], "release": __version_info__[3]};
 if(__version_info__[3] is None):
  return {"major": __version_info__[0], "minor": __version_info__[1], "build": __version_info__[2], "release": None};
__version_date_info__ = (2021, 3, 10, "RC 1", 1);
def version_date():
 if(__version_date_info__[3] is not None):
  return {"year":__version_date_info__[0], "month": __version_date_info__[1], "day": __version_date_info__[2], "release": __version_date_info__[3]};
 if(__version_date_info__[3] is None):
  return {"year":__version_date_info__[0], "month": __version_date_info__[1], "day": __version_date_info__[2], "release": None};
__version_date__ = "{year}.{month}.{day}".format(year=__version_date_info__[0], month=__version_date_info__[1], day=__version_date_info__[2]);
__version_date_alt__ = "{year}.{month}.{day} {release}".format(year=__version_date_info__[0], month=__version_date_info__[1], day=__version_date_info__[2], release=__version_date_info__[2]);
if(__version_date_info__[4] is not None):
 __version_date_plusrc__ = __version_date__+"-"+str(__version_date_info__[4]);
if(__version_date_info__[4] is None):
 __version_date_plusrc__ = __version_date__;
if(__version_info__[4] is not None):
 __version_plusrc__ = __version__+"-"+str(__version_info__[4]);
if(__version_info__[4] is None):
 __version_plusrc__ = __version__;
